CircleListViewport class
A viewport showing a subset of children on a wheel.
Typically used with CircleListScrollView, this viewport is similar to Viewport in that it shows a subset of children in a scrollable based on the scrolling offset and the children's dimensions. But uses RenderCircleListViewport to display the children on a wheel.
See also:
- CircleListScrollView, widget that combines this viewport with a scrollable.
- RenderCircleListViewport, the render object that renders the children on a wheel.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- RenderObjectWidget
- CircleListViewport
Constructors
- CircleListViewport({Key? key, required double itemExtent, bool clipToSize = true, bool renderChildrenOutsideViewport = false, required ViewportOffset offset, required CircleListChildDelegate childDelegate, required Axis axis, double radius = 100})
-
Creates a viewport where children are rendered onto a wheel.
const
Properties
- axis → Axis
-
final
- childDelegate → CircleListChildDelegate
-
A delegate that lazily instantiates children.
final
- clipToSize → bool
-
Whether to clip painted children to the inside of this viewport.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemExtent → double
-
The size of the children along the main axis. Children RenderBoxes will
be given the BoxConstraints of this exact size.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → ViewportOffset
-
ViewportOffset object describing the content that should be visible
in the viewport.
final
- radius → double
-
final
- renderChildrenOutsideViewport → bool
-
Whether to paint children inside the viewport only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → CircleListElement -
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
override
-
createRenderObject(
BuildContext context) → RenderCircleListViewport -
Creates an instance of the RenderObject class that this
RenderObjectWidget represents, using the configuration described by this
RenderObjectWidget.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didUnmountRenderObject(
covariant RenderObject renderObject) → void -
This method is called when a RenderObject that was previously
associated with this widget is removed from the render tree.
The provided RenderObject will be of the same type as the one created by
this widget's createRenderObject method.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateRenderObject(
BuildContext context, covariant RenderCircleListViewport renderObject) → void -
Copies the configuration described by this RenderObjectWidget to the
given RenderObject, which will be of the same type as returned by this
object's createRenderObject.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited